@@ -1,14 +1,13 @@
 use crate::ast::{CharOrRange, Regex, Var};
 use crate::builtin::BUILTIN_RANGES;
+use crate::collections::Map;
 use crate::nfa::{StateIdx, NFA};
 
 use std::convert::TryFrom;
 
-use fxhash::FxHashMap;
-
 pub fn add_re<A>(
     nfa: &mut NFA<A>,
-    bindings: &FxHashMap<Var, Regex>,
+    bindings: &Map<Var, Regex>,
     re: &Regex,
     current: StateIdx,
     cont: StateIdx,
@@ -115,5 +114,13 @@ pub fn add_re<A>(
             nfa.add_empty_transition(current, re1_init);
             nfa.add_empty_transition(current, re2_init);
         }
+
+        Regex::Any => {
+            nfa.add_any_transition(current, cont);
+        }
+
+        Regex::EndOfInput => {
+            nfa.add_end_of_input_transition(current, cont);
+        }
     }
 }
